package api

import (
	"cmf/db/model"
	"cmf/db/repo"
	"cmf/log"
	"errors"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func Nav(r *GinRouter) {
	r.POSTJWT("/nav/create", CreateNav)
	r.POSTJWT("/nav/delete/:id", DeleteNav)
	r.GETJWT("/nav/list", NavList)
	r.GETJWT("/nav/detail/:id", NavDetail)
	r.POSTJWT("/nav/update", UpdateNav)
}

func CreateNav(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	var nav model.Nav
	err := c.ShouldBindJSON(&nav)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	nav.CreateTime = time.Now()
	nav.UpdateTime = time.Now()
	return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionNav, &nav)
}

func DeleteNav(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoDeleteDoc(apictx.CreateRepoCtx(), repo.CollectionNav, _id)
}

func NavList(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	page, size, query := UtilQueryPageSize(c)
	return repo.RepoPageSearch(apictx.CreateRepoCtx(), &repo.PageSearchOptions{
		CollectName: repo.CollectionNav,
		Page:        page,
		Size:        size,
		Query:       query,
		Sort:        bson.D{bson.E{Key: "sort", Value: 1}, bson.E{Key: "createTime", Value: -1}},
	})
}

func NavDetail(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	cate := &model.Nav{}
	found, err := repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
		CollectName: repo.CollectionNav,
		Query:       repo.Map{"_id": id},
	}, cate)
	if err != nil {
		log.Error(err)
		return nil, err
	}

	if !found {
		return nil, errors.New("未找到该数据")
	}
	return cate, nil
}

func UpdateNav(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	var cate model.Nav
	err := c.ShouldBindJSON(&cate)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	if cate.Id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionNav, cate.Id.Hex(), &cate)
}
